@@ -1,4 +1,7 @@
 #!/bin/sh
+
+source ./hack/go-mod-env.sh
+
 REPO=https://github.com/kiegroup/kie-cloud-operator
 BRANCH=$(go run getversion.go -operator)
 REGISTRY=quay.io/kiegroup
@@ -7,17 +10,22 @@ TAR=${BRANCH}.tar.gz
 URL=${REPO}/archive/${TAR}
 CFLAGS="docker"
 
-go generate ./...
 if [[ -z ${CI} ]]; then
     ./hack/go-test.sh
-    echo
-    echo Will build console first:
-    echo
-    CGO_ENABLED=0 GOOS=linux GOARCH=amd64 go build -v -a -o build/_output/bin/console-cr-form github.com/kiegroup/kie-cloud-operator/cmd/ui
-    echo
+fi
+
+./hack/go-gen.sh
+
+echo
+echo Will build console first:
+echo
+CGO_ENABLED=0 GOOS=linux GOARCH=amd64 go build -v -mod=vendor -a -o build/_output/bin/console-cr-form ./cmd/ui
+echo
+
+if [[ -z ${CI} ]]; then
     echo Now building operator:
     echo
-    operator-sdk build ${REGISTRY}/${IMAGE}:${BRANCH}
+    operator-sdk build --go-build-args -mod=vendor ${REGISTRY}/${IMAGE}:${BRANCH}
     if [[ ${1} == "rhel" ]]; then
         if [[ ${LOCAL} != true ]]; then
             CFLAGS="osbs"
@@ -35,6 +43,5 @@ if [[ -z ${CI} ]]; then
             ${CFLAGS}
     fi
 else
-    CGO_ENABLED=0 GOOS=linux GOARCH=amd64 go build -v -a -o build/_output/bin/console-cr-form github.com/kiegroup/kie-cloud-operator/cmd/ui
-    CGO_ENABLED=0 GOOS=linux GOARCH=amd64 go build -v -a -o build/_output/bin/kie-cloud-operator github.com/kiegroup/kie-cloud-operator/cmd/manager
+    CGO_ENABLED=0 GOOS=linux GOARCH=amd64 go build -v -mod=vendor -a -o build/_output/bin/kie-cloud-operator ./cmd/manager
 fi
