@@ -1,10 +1,12 @@
 package apis
 
 import (
+	monv1 "github.com/coreos/prometheus-operator/pkg/apis/monitoring/v1"
 	v1 "github.com/kiegroup/kie-cloud-operator/pkg/apis/app/v1"
 	api "github.com/kiegroup/kie-cloud-operator/pkg/apis/app/v2"
 	oappsv1 "github.com/openshift/api/apps/v1"
 	buildv1 "github.com/openshift/api/build/v1"
+	consolev1 "github.com/openshift/api/console/v1"
 	oimagev1 "github.com/openshift/api/image/v1"
 	routev1 "github.com/openshift/api/route/v1"
 	operatorsv1alpha1 "github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators/v1alpha1"
@@ -16,11 +18,13 @@ func init() {
 	AddToSchemes = append(AddToSchemes,
 		api.SchemeBuilder.AddToScheme,
 		v1.SchemeBuilder.AddToScheme,
-		rbacv1.SchemeBuilder.AddToScheme,
+		rbacv1.AddToScheme,
 		oappsv1.Install,
 		routev1.Install,
 		oimagev1.Install,
 		buildv1.Install,
-		operatorsv1alpha1.SchemeBuilder.AddToScheme,
+		operatorsv1alpha1.AddToScheme,
+		monv1.AddToScheme,
+		consolev1.Install,
 	)
 }
