@@ -14,10 +14,12 @@ import (
 	"github.com/RHsyseng/operator-utils/pkg/resource/read"
 	"github.com/RHsyseng/operator-utils/pkg/resource/write"
 	api "github.com/kiegroup/kie-cloud-operator/pkg/apis/app/v2"
+	"github.com/kiegroup/kie-cloud-operator/pkg/components"
 	"github.com/kiegroup/kie-cloud-operator/pkg/controller/kieapp/constants"
 	"github.com/kiegroup/kie-cloud-operator/pkg/controller/kieapp/shared"
 	routev1 "github.com/openshift/api/route/v1"
 	operatorsv1alpha1 "github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators/v1alpha1"
+	"golang.org/x/mod/semver"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
@@ -27,7 +29,7 @@ import (
 	"k8s.io/apimachinery/pkg/util/intstr"
 )
 
-var name = "console-cr-form"
+var consoleName = "console-cr-form"
 var operatorName string
 
 func shouldDeployConsole() bool {
@@ -48,9 +50,34 @@ func deployConsole(reconciler *Reconciler, operator *appsv1.Deployment) {
 	roleBinding := getRoleBinding(namespace)
 	sa := getServiceAccount(namespace)
 	image := getImage(operator)
-	pod := getPod(namespace, image, sa.Name, operator)
-	service := getService(namespace)
+	pod := getPod(namespace, image, sa.Name, reconciler.OcpVersion, operator)
+	service := getService(namespace, reconciler.OcpVersion)
 	route := getRoute(namespace)
+	// `inject-trusted-cabundle` ConfigMap only supported in OCP 4.2+
+	if semver.Compare(reconciler.OcpVersion, "v4.2") >= 0 || reconciler.OcpVersion == "" {
+		existing := &corev1.ConfigMap{}
+		new := getCaConfigMap(namespace)
+		new.SetOwnerReferences(operator.GetOwnerReferences())
+		if err := reconciler.Service.Get(context.TODO(), types.NamespacedName{Name: new.Name, Namespace: new.Namespace}, existing); err != nil {
+			if errors.IsNotFound(err) {
+				log.Info("Creating ConfigMap ", new.Name)
+				if err := reconciler.Service.Create(context.TODO(), new); err != nil {
+					log.Error("failed to create configmap", err)
+				}
+			} else {
+				log.Error("failed to get configmap", err)
+			}
+		} else {
+			if !reflect.DeepEqual(existing.Labels, new.Labels) {
+				existing.Labels = new.Labels
+				existing.SetOwnerReferences(operator.GetOwnerReferences())
+				log.Info("Updating ConfigMap ", existing.Name)
+				if err := reconciler.Service.Update(context.TODO(), existing); err != nil {
+					log.Error("failed to update configmap", err)
+				}
+			}
+		}
+	}
 	requested := compare.NewMapBuilder().Add(role, roleBinding, sa, pod, service, route).ResourceMap()
 	deployed, err := loadCounterparts(reconciler, namespace, requested)
 	if err != nil {
@@ -123,7 +150,7 @@ func updateCSVlinks(reconciler *Reconciler, route *routev1.Route, operator *apps
 	}
 	url := fmt.Sprintf("https://%s", found.Spec.Host)
 	csv := reconciler.getCSV(operator)
-	if reflect.DeepEqual(csv, &operatorsv1alpha1.ClusterServiceVersion{}) {
+	if reflect.ValueOf(csv).IsNil() {
 		log.Info("No ClusterServiceVersion found, likely because no such owner was set on the operator. This might be because the operator was not installed through OLM")
 		return
 	}
@@ -158,15 +185,15 @@ func getConsoleLink(csv *operatorsv1alpha1.ClusterServiceVersion) *operatorsv1al
 	return nil
 }
 
-func getPod(namespace string, image string, sa string, operator *appsv1.Deployment) *corev1.Pod {
+func getPod(namespace, image, sa, ocpVersion string, operator *appsv1.Deployment) *corev1.Pod {
 	labels := map[string]string{
 		"app":  operatorName,
-		"name": name,
+		"name": consoleName,
 	}
-	volume := corev1.Volume{Name: "proxy-tls"}
+	volume := corev1.Volume{Name: operatorName + "-proxy-tls"}
 	volume.Secret = &corev1.SecretVolumeSource{SecretName: volume.Name}
 	sar, err := json.Marshal(map[string]string{
-		"name":      name,
+		"name":      consoleName,
 		"namespace": namespace,
 		"resource":  "services",
 		"verb":      "patch",
@@ -178,17 +205,31 @@ func getPod(namespace string, image string, sa string, operator *appsv1.Deployme
 	if shared.EnvVarSet(constants.DebugTrue, operator.Spec.Template.Spec.Containers[0].Env) {
 		debug = constants.DebugTrue
 	}
-
-	oauthImage := constants.OauthImageURL
-	if val, exists := os.LookupEnv(constants.OauthVar); exists {
+	var ocpMajor, ocpMinor string
+	splitVersion := strings.Split(strings.TrimPrefix(ocpVersion, "v"), ".")
+	if len(splitVersion) > 1 {
+		ocpMajor = splitVersion[0]
+		ocpMinor = splitVersion[1]
+	}
+	// set oauth image by ocp version, default to latest available
+	oauthImage := constants.Oauth4ImageLatestURL
+	if val, exists := os.LookupEnv(fmt.Sprintf(constants.OauthVar+"%s.%s", ocpMajor, ocpMinor)); exists {
 		oauthImage = val
+	} else if val, exists := os.LookupEnv(constants.OauthVar + "LATEST"); exists {
+		oauthImage = val
+	}
+	if ocpMajor == "3" {
+		oauthImage = constants.Oauth3ImageLatestURL
+		if val, exists := os.LookupEnv(constants.OauthVar + "3"); exists {
+			oauthImage = val
+		}
 	}
 	sarString := fmt.Sprintf("--openshift-sar=%s", sar)
 	httpPort := int32(8080)
 	httpsPort := int32(8443)
-	return &corev1.Pod{
+	pod := &corev1.Pod{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      name,
+			Name:      consoleName,
 			Namespace: namespace,
 			Labels:    labels,
 		},
@@ -208,6 +249,7 @@ func getPod(namespace string, image string, sa string, operator *appsv1.Deployme
 						"--provider=openshift",
 						sarString,
 						fmt.Sprintf("--openshift-service-account=%s", sa),
+						"--openshift-ca=/var/run/secrets/kubernetes.io/serviceaccount/ca.crt",
 						"--tls-cert=/etc/tls/private/tls.crt",
 						"--tls-key=/etc/tls/private/tls.key",
 						"--cookie-secret=SECRET",
@@ -215,7 +257,7 @@ func getPod(namespace string, image string, sa string, operator *appsv1.Deployme
 					VolumeMounts: []corev1.VolumeMount{{Name: volume.Name, MountPath: "/etc/tls/private"}},
 				},
 				{
-					Name:            name,
+					Name:            consoleName,
 					Image:           image,
 					ImagePullPolicy: operator.Spec.Template.Spec.Containers[0].ImagePullPolicy,
 					Command: []string{
@@ -248,6 +290,23 @@ func getPod(namespace string, image string, sa string, operator *appsv1.Deployme
 			},
 		},
 	}
+	// `inject-trusted-cabundle` ConfigMap only supported in OCP 4.2+
+	if semver.Compare(ocpVersion, "v4.2") >= 0 || ocpVersion == "" {
+		caVolume := corev1.Volume{
+			Name: operatorName + "-trusted-cabundle",
+		}
+		caVolume.ConfigMap = &corev1.ConfigMapVolumeSource{
+			Items: []corev1.KeyToPath{{Key: "ca-bundle.crt", Path: "ca-bundle.crt"}},
+		}
+		caVolume.ConfigMap.Name = caVolume.Name
+		pod.Spec.Volumes = append(pod.Spec.Volumes, caVolume)
+		mountPath := "/etc/pki/ca-trust/extracted/crt"
+		pod.Spec.Containers[0].Args = append(pod.Spec.Containers[0].Args, "--openshift-ca="+mountPath+"/"+caVolume.ConfigMap.Items[0].Key)
+		pod.Spec.Containers[0].VolumeMounts = append(pod.Spec.Containers[0].VolumeMounts, corev1.VolumeMount{Name: caVolume.Name, MountPath: mountPath, ReadOnly: true})
+	} else {
+		log.Warn(err)
+	}
+	return pod
 }
 
 func getImage(operator *appsv1.Deployment) string {
@@ -255,19 +314,17 @@ func getImage(operator *appsv1.Deployment) string {
 	return image
 }
 
-func getService(namespace string) *corev1.Service {
+func getService(namespace, ocpVersion string) *corev1.Service {
 	labels := map[string]string{
 		"app":  operatorName,
-		"name": name,
+		"name": consoleName,
 	}
-	return &corev1.Service{
+	svc := &corev1.Service{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      name,
-			Namespace: namespace,
-			Annotations: map[string]string{
-				"service.alpha.openshift.io/serving-cert-secret-name": "proxy-tls",
-			},
-			Labels: labels,
+			Name:        consoleName,
+			Namespace:   namespace,
+			Annotations: map[string]string{"service.beta.openshift.io/serving-cert-secret-name": operatorName + "-proxy-tls"},
+			Labels:      labels,
 		},
 		Spec: corev1.ServiceSpec{
 			Ports: []corev1.ServicePort{
@@ -280,23 +337,27 @@ func getService(namespace string) *corev1.Service {
 			Selector: labels,
 		},
 	}
+	if semver.Major(ocpVersion) == "v3" {
+		svc.Annotations = map[string]string{"service.alpha.openshift.io/serving-cert-secret-name": operatorName + "-proxy-tls"}
+	}
+	return svc
 }
 
 func getRoute(namespace string) *routev1.Route {
 	labels := map[string]string{
 		"app":  operatorName,
-		"name": name,
+		"name": consoleName,
 	}
 	return &routev1.Route{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      name,
+			Name:      consoleName,
 			Namespace: namespace,
 			Labels:    labels,
 		},
 		Spec: routev1.RouteSpec{
 			To: routev1.RouteTargetReference{
 				Kind: "Service",
-				Name: name,
+				Name: consoleName,
 			},
 			TLS: &routev1.TLSConfig{
 				Termination: routev1.TLSTerminationReencrypt,
@@ -305,26 +366,36 @@ func getRoute(namespace string) *routev1.Route {
 	}
 }
 
+func getCaConfigMap(namespace string) *corev1.ConfigMap {
+	labels := map[string]string{
+		"app": operatorName,
+		"config.openshift.io/inject-trusted-cabundle": "true",
+	}
+	return &corev1.ConfigMap{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      operatorName + "-trusted-cabundle",
+			Namespace: namespace,
+			Labels:    labels,
+		},
+	}
+}
+
 func getRole(namespace string) *rbacv1.Role {
 	labels := map[string]string{
 		"app":  operatorName,
-		"name": name,
+		"name": consoleName,
 	}
 	return &rbacv1.Role{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      name,
+			Name:      consoleName,
 			Namespace: namespace,
 			Labels:    labels,
 		},
 		Rules: []rbacv1.PolicyRule{
 			{
 				APIGroups: []string{api.SchemeGroupVersion.Group},
-				Resources: []string{"*"},
-				Verbs:     []string{"*"},
-				/*
-					Resources: []string{"kieapps"},
-					Verbs:     components.Verbs,
-				*/
+				Resources: []string{"kieapps"},
+				Verbs:     components.Verbs,
 			},
 		},
 	}
@@ -333,22 +404,22 @@ func getRole(namespace string) *rbacv1.Role {
 func getRoleBinding(namespace string) *rbacv1.RoleBinding {
 	labels := map[string]string{
 		"app":  operatorName,
-		"name": name,
+		"name": consoleName,
 	}
 	return &rbacv1.RoleBinding{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      name,
+			Name:      consoleName,
 			Namespace: namespace,
 			Labels:    labels,
 		},
 		RoleRef: rbacv1.RoleRef{
 			Kind: "Role",
-			Name: name,
+			Name: consoleName,
 		},
 		Subjects: []rbacv1.Subject{
 			{
 				Kind: "ServiceAccount",
-				Name: name,
+				Name: consoleName,
 			},
 		},
 	}
@@ -357,7 +428,7 @@ func getRoleBinding(namespace string) *rbacv1.RoleBinding {
 func getServiceAccount(namespace string) *corev1.ServiceAccount {
 	labels := map[string]string{
 		"app":  operatorName,
-		"name": name,
+		"name": consoleName,
 	}
 	type reference struct {
 		Kind string `json:"kind"`
@@ -373,7 +444,7 @@ func getServiceAccount(namespace string) *corev1.ServiceAccount {
 		APIVersion: "v1",
 		Reference: reference{
 			Kind: "Route",
-			Name: name,
+			Name: consoleName,
 		},
 	})
 	if err != nil {
@@ -381,7 +452,7 @@ func getServiceAccount(namespace string) *corev1.ServiceAccount {
 	}
 	return &corev1.ServiceAccount{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      name,
+			Name:      consoleName,
 			Namespace: namespace,
 			Labels:    labels,
 			Annotations: map[string]string{
